@@ -62,9 +62,14 @@ class JsonDeserializable:
         :param json_type:
         :return:
         """
+        try:
+            str_types = (str, unicode)
+        except NameError:
+            str_types = (str,)
+
         if type(json_type) == dict:
             return json_type
-        elif type(json_type) == str:
+        elif type(json_type) in str_types:
             return json.loads(json_type)
         else:
             raise ValueError("json_type should be a json dict or string.")
@@ -86,22 +91,27 @@ class Update(JsonDeserializable):
         obj = cls.check_json(json_type)
         update_id = obj['update_id']
         message = None
+        edited_message = None
         inline_query = None
         chosen_inline_result = None
         callback_query = None
         if 'message' in obj:
             message = Message.de_json(obj['message'])
+        if 'edited_message' in obj:
+            edited_message = Message.de_json(obj['edited_message'])
         if 'inline_query' in obj:
             inline_query = InlineQuery.de_json(obj['inline_query'])
         if 'chosen_inline_result' in obj:
             chosen_inline_result = ChosenInlineResult.de_json(obj['chosen_inline_result'])
         if 'callback_query' in obj:
             callback_query = CallbackQuery.de_json(obj['callback_query'])
-        return cls(update_id, message, inline_query, chosen_inline_result, callback_query)
+        return cls(update_id, message, edited_message, inline_query, chosen_inline_result, callback_query)
 
-    def __init__(self, update_id, message, inline_query, chosen_inline_result, callback_query):
+    def __init__(self, update_id, message, edited_message, inline_query, chosen_inline_result, callback_query):
         self.update_id = update_id
+        self.edited_message = edited_message
         self.message = message
+        self.edited_message = edited_message
         self.inline_query = inline_query
         self.chosen_inline_result = chosen_inline_result
         self.callback_query = callback_query
@@ -178,6 +188,8 @@ class Message(JsonDeserializable):
             opts['forward_date'] = obj['forward_date']
         if 'reply_to_message' in obj:
             opts['reply_to_message'] = Message.de_json(obj['reply_to_message'])
+        if 'edit_date' in obj:
+            opts['edit_date'] = obj.get('edit_date')
         if 'text' in obj:
             opts['text'] = obj['text']
             content_type = 'text'
@@ -269,6 +281,7 @@ class Message(JsonDeserializable):
         self.forward_from = None
         self.forward_date = None
         self.reply_to_message = None
+        self.edit_date = None
         self.text = None
         self.entities = None
         self.audio = None
@@ -304,13 +317,17 @@ class MessageEntity(JsonDeserializable):
         offset = obj['offset']
         length = obj['length']
         url = obj.get('url')
-        return cls(type, offset, length, url)
+        user = None
+        if 'user' in obj:
+            user = User.de_json(obj['user'])
+        return cls(type, offset, length, url, user)
 
-    def __init__(self, type, offset, length, url=None):
+    def __init__(self, type, offset, length, url=None, user=None):
         self.type = type
         self.offset = offset
         self.length = length
         self.url = url
+        self.user = user
 
 
 class PhotoSize(JsonDeserializable):
@@ -716,6 +733,19 @@ class CallbackQuery(JsonDeserializable):
         self.inline_message_id = inline_message_id
 
 
+class ChatMember(JsonDeserializable):
+    @classmethod
+    def de_json(cls, json_type):
+        obj = cls.check_json(json_type)
+        user = User.de_json(obj['user'])
+        status = obj['status']
+        return cls(user, status)
+
+    def __init__(self, user, status):
+        self.user = user
+        self.status = status
+
+
 # InlineQuery
 
 class InlineQuery(JsonDeserializable):
